<?php // Simple File List | Search Extension | Script: ee-ini.php | Author: Mitchell Bennis | support@simplefilelist.com | Revised: 11.25.2019
	
// Included in the main Simple File List plugin file setup function.

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
if ( ! wp_verify_nonce( $eeSFL_Nonce, 'eeSFL_Include' )) exit('ERROR 98'); // Exit if nonce fails

$eeSFL_Log['eeSFLS'][] = 'Loading the Search & Pagination Extension ...';

global $eeSFLS; // Important

$eeSFLS_Settings = array(); // Used for install/update below


// Version Check
if( defined('eeSFL_Version') ) {
		
	$eeSFLS_Nonce = wp_create_nonce('eeSFLS_Include'); // Security
	include_once(__DIR__ . '/includes/eeSFLS_class.php'); // Get Class File
	$eeSFLS = new eeSFLS_class(); // Initiate the Search Class
	if(is_object($eeSFLS)) { $eeSFL_Log['eeSFLS'][] = 'Class Loaded'; }
	
	// Update Plugin if Needed
	if( get_option('eeSFL-1-EnableSearch') ) { // SFLF 1 Installed
		
		$eeSFL_Log['eeSFLS'][] = 'Migrating Search Extension Settings...';
		
		$eeSFLS_Settings['EnableSearch'] = get_option('eeSFL-1-EnableSearch'); // Convert to new
		$eeSFLS_Settings['EnablePagination'] = get_option('eeSFL-1-EnablePagination');
		$eeSFLS_Settings['FilesPerPage'] = get_option('eeSFL-1-FilesPerPage');
		
		delete_option('eeSFL-1-EnableSearch'); // Out with the old
		delete_option('eeSFL-1-EnablePagination');
		delete_option('eeSFL-1-FilesPerPage');
	
	} elseif(!@$eeSFL_Config['EnableSearch']) { // Nothing installed or empty value
		
		$eeSFL_Log['eeSFLS'][] = 'Adding Search Extension Settings...';
		
		$eeSFLS_Settings['EnableSearch'] = 'YES'; // Set defaults
		$eeSFLS_Settings['EnablePagination'] = 'YES';
		$eeSFLS_Settings['FilesPerPage'] = $eeSFLS->eeSFLS_FilesPerPageDefault;
	}
	
	if( count($eeSFLS_Settings) == 3 ) { // Add new settings to existing
		
		$eeSettings = get_option('eeSFL-Settings'); // All settings
		
		$eeSFL_Config = array_merge($eeSFL_Config, $eeSFLS_Settings); // Append the new settings
		
		$eeSettings[$eeSFL_ID] = $eeSFL_Config;
		
		update_option('eeSFL-Settings', $eeSettings );
	}

} else {
	
	$eeSFLF_ERROR = '<strong>' . __('SEARCH EXTENSION DISABLED', 'ee-simple-file-list-search') . '</strong><br />' . 
		__('Please update the main Simple File List plugin to the latest version.', 'ee-simple-file-list-search');
	
	if( is_admin() AND @$_GET['page'] == 'ee-simple-file-list') {
		$eeSFL_Log['errors'][] = $eeSFLF_ERROR;
	}
	
}

?>