<?php

/**
 * @package eeSFLS
 */
/*
Plugin Name: Simple File List Search
Plugin URI: http://simplefilelist.com
Description: Adds search and pagination capability to Simple File List
Author: Mitchell Bennis
Version: 2.0.8
Author URI: http://simplefilelist.com
 * Intellectual Property rights, and copyright, reserved by Mitchell Bennis as allowed by law include,
 * but are not limited to, the working concept, function, and behavior of this plugin,
 * the logical code structure and expression as written.
 *
 * @category    Plugin
 * @copyright   Copyright (c) Mitchell Bennis
Text Domain: ee-simple-file-list-search
Domain Path: /languages
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// Plugin version - DON'T FORGET TO UPDATE ABOVE TOO !!!
define('eeSFLS_Version', '2.0.8');

// Check for Update
// https://github.com/YahnisElsts/plugin-update-checker
// https://github.com/eemitch/ee-simple-file-list-extension
// b55251dafad1d9f35c3de273d617aa91840a5cfd

include( plugin_dir_path(__FILE__) . '/updater/plugin-update-checker.php' );
$eeSFLS_updateChecker = Puc_v4_Factory::buildUpdateChecker(
	'https://github.com/eemitch/ee-simple-file-list-search',
	__FILE__,
	'ee-simple-file-list-search'
);
$eeSFLS_updateChecker->setAuthentication('b55251dafad1d9f35c3de273d617aa91840a5cfd');
$eeSFLS_updateChecker->getVcsApi()->enableReleaseAssets();



// Shortcode
function eeSFLS_Shortcode($atts, $content = null) {
	
	// Usage: [eeSFLS permalink="simple-file-list"]
	// Permalink can be a string (page) or number (page id)
    
    global $eeSFLS, $eeSFL_Log, $eeSFL_Config;
    
    $eeOutput = '';
    $eeSFLS_Admin = FALSE; // We are on the front side of the site
	
	$eeSFL_Log['eeSFLS'][] = 'Shortcode Loading: ' . get_permalink();
	
	
    // Over-Riding Shortcode Attributes
	if($atts) {
	
		$atts = shortcode_atts( array( // Use lowercase att names only
			'permalink' => '/'
		), $atts );
		
		extract($atts);
	}
	
	// exit($permalink);
	
	// Get the form
	$eeSFLS_Nonce = wp_create_nonce('eeSFLS_Include'); // Security
	include(plugin_dir_path(__FILE__) . '/includes/ee-search-form.php');
	
	return $eeOutput;

}
add_shortcode( 'eeSFLS', 'eeSFLS_Shortcode' );




// Load stuff we need in the Admin head
function eeSFLS_AdminHead($eeHook) {
        
    // Only load scripts if on these Admin pages.
    $eeHooks = array(
    	'toplevel_page_ee-simple-file-list',
    	'simple-file-list_page_ee-simple-file-list',
    	'simple-file-list_page_ee-simple-file-list-settings'
    );
    
    if(in_array($eeHook, $eeHooks)) {
       	
		$deps = array('jqueryui');
		wp_enqueue_style( 'ee-simple-file-list-search-admin-style', plugins_url( 'css/eeSFLS_adminStyle.css', __FILE__ ), '', '1.1.1' );
		wp_enqueue_style( 'ee-simple-file-list-search-style', plugins_url( 'css/eeSFLS_styles.css', __FILE__ ), '', '1.1.1' );
		wp_enqueue_style('ee-simple-file-list-search-date-picker-css', plugin_dir_url(__FILE__) . 'datepicker/jquery-ui.min.css', '', '1.1.1');
		wp_enqueue_style('ee-simple-file-list-search-date-picker-theme-css', plugin_dir_url(__FILE__) . 'datepicker/jquery-ui.theme.min.css', '', '1.1.1');
		
		wp_enqueue_script('ee-simple-file-list-search-admin-js', plugins_url('js/adminScripts.js', __FILE__) , '', '1.1.1');
		wp_enqueue_script('ee-simple-file-list-search-admin-js-footer', plugins_url('js/adminScriptsFooter.js', __FILE__), $deps, '1', TRUE );
		wp_enqueue_script('ee-simple-file-list-search-js-in-footer', plugin_dir_url(__FILE__) . 'js/scripts.js', '','30',TRUE); // Load in Footer
		wp_enqueue_script('ee-simple-file-list-search-datepicker-js', plugin_dir_url( __FILE__ ) . 'datepicker/jquery-ui.min.js', '', '1.1.1');

    }
}
add_action( 'admin_enqueue_scripts', 'eeSFLS_AdminHead' );





// Load stuff we need in the front-side head
function eeSFLS_Enqueue() {
	
	// Register the style like this for a theme:
    wp_register_style( 'ee-simple-file-list-search-css', plugin_dir_url(__FILE__) . 'css/eeSFLS_styles.css', '', '1.1.1');
    wp_register_style( 'ee-simple-file-list-search-date-picker-css', plugin_dir_url(__FILE__) . 'datepicker/jquery-ui.min.css', '', '1.1.1');
    wp_register_style( 'ee-simple-file-list-search-date-picker-theme-css', plugin_dir_url(__FILE__) . 'datepicker/jquery-ui.theme.min.css', '', '1.1.1');
 
    // Enqueue the style:
    wp_enqueue_style('ee-simple-file-list-search-css');
    wp_enqueue_style('ee-simple-file-list-search-date-picker-css');
    wp_enqueue_style('ee-simple-file-list-search-date-picker-theme-css');
    
    // Javascript
    $deps = array('jquery');
    wp_enqueue_script('ee-simple-file-list-search-js-in-footer', plugin_dir_url(__FILE__) . 'js/scripts.js',$deps,'30',TRUE); // Load in Footer
	wp_enqueue_script('ee-simple-file-list-search-datepicker-js', plugin_dir_url( __FILE__ ) . 'datepicker/jquery-ui.min.js', '', '1.1.1');
}
add_action( 'wp_enqueue_scripts', 'eeSFLS_Enqueue' );




// Language Enabler
function eeSFLS_Textdomain() {
    load_plugin_textdomain( 'ee-simple-file-list-search', FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );
}
add_action( 'init', 'eeSFLS_Textdomain' );



function eeSFLS_Activate() {

	// Registration Check
    $eeExtension = 'ee-simple-file-list-search'; // This Plugin
    
    // This Domain
    $eeDomain = $_SERVER['HTTP_HOST'];
    $eeReturn = FALSE;
    
    // Lucky you, skipping registration check for these ...
    if(strpos($eeDomain, 'ocalhost')) { return TRUE; }
    if(strpos($eeDomain, '.domains')) { return TRUE; }
    if(strpos($eeDomain, '.local')) { return TRUE; }
    if(strpos($eeDomain, '.wpengine')) { return TRUE; }
    if(filter_var($eeDomain, FILTER_VALIDATE_IP)) { return TRUE; }
    
    // Registration Check - Did you pay or are you cheating?
    
    // EE Server
    $eeRegCheckURL = 'http://reg.simplefilelist.com/index.php?eeDomain=' . $eeDomain . 
    
            '&eeExtension=' . $eeExtension . 
            '&eeEmail=' . urlencode( get_option('admin_email') );
        
    
    // This page will return a simple YES or NO based on the extension slug and the current domain.
    // If the current domain is not found, we will check against the admin email and current domain. 
    $eeReturn = file_get_contents($eeRegCheckURL);
    
    
    // Don't activate if this domain is not registered.
    // Activate if ANY REPLY (even errors) or there is no reply
    $eeMsg = __('This plugin extension is not registered.', 'ee-simple-file-list-search');
    
    
    // What to do?
    if($eeReturn == 'NO') { // Maybe I can help
        
        @wp_mail('support@simplefilelist.com', 'SFLS Activation FAIL', 'Simple File List Search failed to activate on ' . $eeDomain);
        
        die($eeMsg); 
        
    } else { // It makes me happy
        
        @wp_mail('support@simplefilelist.com', 'SFLS Activation', 'Simple File List Search activated on ' . $eeDomain . "\n\nReturn: " . $eeReturn);
        
        return TRUE;
    }
}

register_activation_hook( __FILE__, 'eeSFLS_Activate' );
